Crate rins_markdown_parser

Crate rins_markdown_parser 

Structs

Grammar
Parser structure which is used to parse text with the grammar defined in src/grammar.pest. It is automatically generated by pest_derive based on the specified grammar.

Enums

ErrorParse
Enum representing possible errors encountered during parsing or file operations.
Rule

Functions

md_to_html_file
Converts the markdown file at md_path to an HTML file at html_path.
parse_by_rule
Parses the input string according to a specific rule and returns the resulting pairs.
parse_markdown
Parses the given input markdown string and returns a pest::iterators::Pairs of rules.
parse_to_console
Converts the given markdown text to HTML and prints it to the console.
str_to_html
Converts provided text in markdown format to HTML, returning a vector of HTML lines.
to_html
Converts a pest::iterators::Pair representing a single rule into an HTML string.